#
# spec file for package qgpgme
#
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 15
Name:           qgpgme
Version:        2.0.0
Release:        1.1
Summary:        Qt API bindings/wrapper for GPGME
License:        GPL-2.0-or-later
URL:            https://www.gnupg.org/software/gpgme/index.html
Source:         https://www.gnupg.org/ftp/gcrypt/qgpgme/%{name}-%{version}.tar.xz
Source1:        https://www.gnupg.org/ftp/gcrypt/qgpgme/%{name}-%{version}.tar.xz.sig
# https://www.gnupg.org/signature_key.html
Source2:        %{name}.keyring
Source3:        baselibs.conf
BuildRequires:  c++_compiler
BuildRequires:  cmake
BuildRequires:  pkgconfig
BuildRequires:  cmake(Gpgmepp) >= 2.0.0
BuildRequires:  cmake(Qt5Core) >= 5.15.0
BuildRequires:  cmake(Qt6Core) >= 6.5.0
BuildRequires:  cmake(Qt6Test)
BuildRequires:  pkgconfig(gpg-error) >= 1.47
BuildRequires:  pkgconfig(gpgme) >= 2.0.0
%if 0%{?suse_version} < 1600
BuildRequires:  gcc12-c++
%endif

%description
QGpgme provides a very high level Qt API around GpgMEpp.

%package -n libqgpgme%{sover}
Summary:        Qt5 API bindings/wrapper for GPGME

%description -n libqgpgme%{sover}
QGpgme provides a very high level Qt API around GpgMEpp.

This package contains the shared library built for Qt5.

%package -n libqgpgmeqt6-%{sover}
Summary:        Qt6 API bindings/wrapper for GPGME

%description -n libqgpgmeqt6-%{sover}
QGpgme provides a very high level Qt API around GpgMEpp.

This package contains the shared library built for Qt6.

%package -n libqgpgme-devel
Summary:        Development files for %{name} (Qt5)
Requires:       libqgpgme%{sover} = %{version}
Requires:       cmake(Gpgmepp) >= 2.0.0

%description -n libqgpgme-devel
QGpgme provides a very high level Qt API around GpgMEpp.

This package contains the files needed to build using %{name} and Qt5.

%package -n libqgpgmeqt6-devel
Summary:        Development files for %{name} (Qt6)
Requires:       libqgpgmeqt6-%{sover} = %{version}
Requires:       cmake(Gpgmepp) >= 2.0.0

%description -n libqgpgmeqt6-devel
QGpgme provides a very high level Qt API around GpgMEpp.

This package contains the files needed to build using %{name} and Qt6.

%prep
%autosetup -p1

%build
%if 0%{?suse_version} < 1600
export CXX=g++-12
%endif
%cmake \
	-DBUILD_WITH_QT5:BOOL=ON \
	-DBUILD_WITH_QT6:BOOL=ON \
	-DBUILD_TESTING:BOOL=ON \
	%{nil}
%cmake_build

%install
%cmake_install

%check
%ctest

%ldconfig_scriptlets -n libqgpgme%{sover}
%ldconfig_scriptlets -n libqgpgmeqt6-%{sover}

%files -n libqgpgme%{sover}
%license COPYING
%{_libdir}/libqgpgme.so.%{sover}{,.*}

%files -n libqgpgmeqt6-%{sover}
%license COPYING
%{_libdir}/libqgpgmeqt6.so.%{sover}{,.*}

%files -n libqgpgme-devel
%license COPYING
%doc ChangeLog NEWS README VERSION
%{_libdir}/libqgpgme.so
%{_includedir}/qgpgme-qt5
%{_libdir}/cmake/QGpgme

%files -n libqgpgmeqt6-devel
%license COPYING
%doc ChangeLog NEWS README VERSION
%{_libdir}/libqgpgmeqt6.so
%{_includedir}/qgpgme-qt6
%{_libdir}/cmake/QGpgmeQt6

%changelog
* Thu Jul 17 2025 Andreas Stieger <andreas.stieger@gmx.de>
- Add requirements to gpgmepp to -devel packages to avoid breaking
  plasma-pass, and correctness
* Thu Jul 17 2025 Andreas Stieger <andreas.stieger@gmx.de>
- disable 32-bit libraries for Qt6 flavor
* Wed Jul 16 2025 Andreas Stieger <andreas.stieger@gmx.de>
- enable Qt5 for Kf5 kwallet boo#1244605
* Fri Jun 13 2025 Andreas Stieger <andreas.stieger@gmx.de>
- initial version, upstream split the language bindings from 2.0.0
